@@ -2,23 +2,20 @@
 #######################################################################
 """ Hierarchy Climbing adapters to adapt to IFriendshipAnnotation
 
-$Id: friendshipadapter.py 51563 2008-08-31 09:41:23Z cray $
+$Id: friendshipadapter.py 51919 2008-10-21 19:01:53Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51563 $"
+__version__ = "$Revision: 51919 $"
 
 from ng.content.annotation.friendshipannotation.interfaces import IFriendshipAnnotation
 from zope.app.container.contained import IContained
 
 def FriendshipAdapter(context) :
-    print "friendship adapter",context
     an = IFriendshipAnnotation(IContained(context).__parent__)
-    print "return", an
     return an
         
 def Site2FriendshipAdapter(context) :
-    print "friendship site",context
     raise LookupError
   
     
\ No newline at end of file
